@@ -35,10 +35,16 @@
 
 #include "library/gnome-keyring.h"
 
+#include "pk/gkr-pk-object-storage.h"
+#ifdef ROOT_CERTIFICATES
+#include "pk/gkr-pk-root-storage.h"
+#endif
+
 #include "pkcs11/gkr-pkcs11-daemon.h"
 
 #ifdef WITH_SSH
 #include "ssh/gkr-ssh-daemon.h"
+#include "ssh/gkr-ssh-storage.h"
 #endif
 
 #include "ui/gkr-ask-daemon.h"
@@ -429,10 +435,10 @@ main (int argc, char *argv[])
 	GIOChannel *channel;
 	GMainContext *ctx;
 	gchar *login_password;
+	unsigned seed;
 	
 	g_type_init ();
 	g_thread_init (NULL);
-	srand (time (NULL));
 	
 	parse_arguments (&argc, &argv);
 
@@ -449,6 +455,18 @@ main (int argc, char *argv[])
 
 	gkr_crypto_setup ();
 
+	gcry_create_nonce (&seed, sizeof (seed));
+	srand (seed);
+	
+	/* Initialize object storage */
+	if (!gkr_pk_object_storage_initialize ())
+		cleanup_and_exit (1);
+	
+#ifdef ROOT_CERTIFICATES
+	if (!gkr_pk_root_storage_initialize ())
+		cleanup_and_exit (1);
+#endif
+
 	/* Initialize the appropriate components */
 	if (check_run_component ("keyring")) {
 		if (!gkr_daemon_io_create_master_socket ())
@@ -457,7 +475,8 @@ main (int argc, char *argv[])
 
 #ifdef WITH_SSH	
 	if (check_run_component ("ssh")) {
-		if (!gkr_daemon_ssh_io_initialize ())
+		if (!gkr_daemon_ssh_io_initialize () ||
+		    !gkr_ssh_storage_initialize ())
 			cleanup_and_exit (1);
 	}
 #endif
