@@ -417,8 +417,6 @@ gkr_pk_storage_load (GkrPkStorage *storage, GkrPkObject *obj, GError **err)
 	g_return_val_if_fail (GKR_IS_PK_STORAGE (storage), FALSE);
 	klass = GKR_PK_STORAGE_GET_CLASS (storage);
 	g_return_val_if_fail (klass->load, FALSE);
-	
-g_message("loading location: %s", obj->location ? g_quark_to_string (obj->location) : "NONE");
 	return (klass->load) (storage, obj, err);	
 }
 
@@ -659,7 +657,7 @@ gkr_pk_storage_get_store_password (GkrPkStorage *storage, GQuark location, gkrco
 	gchar *custom_label = NULL;
 	gchar *secondary;
 	gchar *display = NULL;
-	gboolean ret;
+	gboolean ret = TRUE;
 	guint flags;
 	GkrPkIndex *index;
 	GkrKeyring *login;
@@ -743,7 +741,7 @@ gkr_pk_storage_get_load_password (GkrPkStorage *storage, GQuark location, gkrcon
 	gchar *stype, *secondary;
 	gchar *display = NULL;
 	const gchar *password;
-	gboolean ret;
+	gboolean ret = TRUE;
 	GkrPkIndex *index;
 	gint st;
 	guint flags;
@@ -793,7 +791,7 @@ gkr_pk_storage_get_load_password (GkrPkStorage *storage, GQuark location, gkrcon
 		
 	/* See if we can find a valid password for this location */
 	if (st == 2) {
-		*result = gkr_pk_index_get_secret (index, digest);
+		*result = gkr_secure_strdup (gkr_pk_index_get_secret (index, digest));
 		if (*result != NULL)
 			return TRUE;
 		
